@@ -81,6 +81,9 @@ case $type in
         echo "______________________________________________________________________"
         echo ""
         echo "${T_MD}STEP 1: Generating RSA private key (1024 bit) [server.key]${T_ME}"
+        if [ ! -f $HOME/.rnd ]; then
+            touch $HOME/.rnd
+        fi
         if [ ".$randfiles" != . ]; then
             $ssleay genrsa -rand $randfiles \
                            -out $sslkeydir/server.key \
@@ -187,6 +190,9 @@ EOT
         echo "______________________________________________________________________"
         echo ""
         echo "${T_MD}STEP 1: Generating RSA private key for CA (1024 bit)${T_ME}"
+        if [ ! -f $HOME/.rnd ]; then
+            touch $HOME/.rnd
+        fi
         if [ ".$randfiles" != . ]; then
             $ssleay genrsa -rand $randfiles \
                            -out $sslkeydir/ca.key \
@@ -249,6 +255,9 @@ EOT
         echo "______________________________________________________________________"
         echo ""
         echo "${T_MD}STEP 4: Generating RSA private key for SERVER (1024 bit)${T_ME}"
+        if [ ! -f $HOME/.rnd ]; then
+            touch $HOME/.rnd
+        fi
         if [ ".$randfiles" != . ]; then
             $ssleay genrsa -rand $randfiles \
                            -out $sslkeydir/server.key \
