@@ -667,6 +667,7 @@ static void init_GetCertAndKey(server_rec *s, pool *p, SSLConfigRec *pConfig)
 {
     FILE *f;
     char szPath[MAX_STRING_LEN];
+    char *cpPath;
 
     /*  
      *  Check for problematic re-initializations
@@ -723,7 +724,9 @@ static void init_GetCertAndKey(server_rec *s, pool *p, SSLConfigRec *pConfig)
     /*
      * Read server certificate
      */
-    if ((f = ap_pfopen(p, pConfig->szCertificateFile, "r")) == NULL) {
+    cpPath = ap_server_root_relative(p, pConfig->szCertificateFile);
+    ap_cpystrn(szPath, cpPath, sizeof(szPath));     
+    if ((f = ap_pfopen(p, szPath, "r")) == NULL) {
         ap_snprintf(szPath, sizeof(szPath), "%s/%s", 
                     __SSLeay X509_get_default_cert_dir(),
                     pConfig->szCertificateFile);
@@ -735,10 +738,6 @@ static void init_GetCertAndKey(server_rec *s, pool *p, SSLConfigRec *pConfig)
             exit(1);
         }
     }
-    else {
-        /* in case it also contains the key */
-        ap_cpystrn(szPath, pConfig->szCertificateFile, sizeof(szPath));
-    }
     pConfig->px509Certificate = __SSLeay X509_new();
     if (!__SSLeay PEM_read_X509(f, &pConfig->px509Certificate, NULL)) {
         ap_log_error(APLOG_MARK, APLOG_ERR|APLOG_NOERRNO, s,
@@ -866,7 +865,7 @@ static int init_VerifyFlags(SSLConfigRec *pConfig)
      * Immediately stop processing if SSL is disabled for
      * this connection
      */
-    if (pConfig->bDisabled) {
+    if (pConfig == NULL || pConfig->bDisabled) {
         fb->ssl = NULL;
         return TRUE;
     }
